//<!--
// The contents of this file are subject to the terms
// of the Common Development and Distribution License
// (the License).  You may not use this file except in
// compliance with the License.
// 
// You can obtain a copy of the license at
// https://woodstock.dev.java.net/public/CDDLv1.0.html.
// See the License for the specific language governing
// permissions and limitations under the License.
// 
// When distributing Covered Code, include this CDDL
// Header Notice in each file and include the License file
// at https://woodstock.dev.java.net/public/CDDLv1.0.html.
// If applicable, add the following below the CDDL Header,
// with the fields enclosed by brackets [] replaced by
// you own identifying information:
// "Portions Copyrighted [year] [name of copyright owner]"
// 
// Copyright 2007 Sun Microsystems, Inc. All rights reserved.
//
// This Javascript file should be included in any page that uses the associated
// component, where JSF Extensions is used as the underlying transfer protocol.
//

dojo.provide("webui.suntheme.widget.jsfx.table2RowGroup");

dojo.require("webui.suntheme.widget.table2RowGroup");

/**
 * This function is used to obtain data asynchronously.
 */
webui.suntheme.widget.jsfx.table2RowGroup = {
    /**
     * This function is used to process scroll events.
     *
     * @param evt Event generated by scroll bar.
     */
    processScrollEvent: function(evt) {
        if (evt == null) {
            return false;
        }

        var domNode;
        if (evt.currentTarget) {
            domNode = evt.currentTarget;
        } else {
            return false;
        }

        // Ensure we have a valid element node.
        var src = document.getElementById(domNode.id);

        // Generate AJAX request using the JSF Extensions library.
        new DynaFaces.fireAjaxTransaction((src) ? src : document.forms[0], {
            execute: "none",
            render: domNode.id,
            replaceElement: webui.suntheme.widget.jsfx.table2RowGroup.update,
            xjson: {
                first: domNode._first
            }
        });
        return true;
    },

    /**
     * This function is used to update widgets.
     *
     * @param elementId The HTML element Id.
     * @param content The content returned by the AJAX response.
     * @param closure The closure argument provided to DynaFaces.fireAjaxTransaction.
     * @param xjson The zjson argument provided to DynaFaces.fireAjaxTransaction.
     */
    update: function(elementId, content, closure, xjson) {
        if (elementId == null || content == null) {
            return false;
        }

        // Parse JSON text.
        var json = JSON.parse(content);

        // Add rows.
        var domNode = document.getElementById(elementId);
        domNode._addRows({
            first: xjson.first,
            rows: json
        });

        // Publish an event for custom AJAX implementations to listen for.
        webui.suntheme.widget.table2RowGroup.scroll.publishEndEvent(json);
        return true;
    }
}

// Listen for Dojo Widget events.
dojo.event.topic.subscribe(webui.suntheme.widget.table2RowGroup.scroll.beginEventTopic,
    webui.suntheme.widget.jsfx.table2RowGroup, "processScrollEvent");

//-->
